==> v0.41.9.zip: postgres-formula/AUTHORS.md <==
# Authors

This list is sorted by the number of commits per contributor in _descending_ order.

Avatar|Contributor|Contributions
:-:|---|:-:
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/10231489?v=4' width='36' height='36' alt='@myii'>|[@myii](https://github.com/myii)|154
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/13322818?v=4' width='36' height='36' alt='@noelmcloughlin'>|[@noelmcloughlin](https://github.com/noelmcloughlin)|78
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/1800660?v=4' width='36' height='36' alt='@aboe76'>|[@aboe76](https://github.com/aboe76)|54
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/1396878?v=4' width='36' height='36' alt='@gravyboat'>|[@gravyboat](https://github.com/gravyboat)|41
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/242396?v=4' width='36' height='36' alt='@javierbertoli'>|[@javierbertoli](https://github.com/javierbertoli)|21
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/3374962?v=4' width='36' height='36' alt='@nmadhok'>|[@nmadhok](https://github.com/nmadhok)|19
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/16338056?v=4' width='36' height='36' alt='@vutny'>|[@vutny](https://github.com/vutny)|18
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/528061?v=4' width='36' height='36' alt='@puneetk'>|[@puneetk](https://github.com/puneetk)|11
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/745513?v=4' width='36' height='36' alt='@EvaSDK'>|[@EvaSDK](https://github.com/EvaSDK)|9
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/1713422?v=4' width='36' height='36' alt='@dferramosi'>|[@dferramosi](https://github.com/dferramosi)|8
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/5306980?v=4' width='36' height='36' alt='@johnkeates'>|[@johnkeates](https://github.com/johnkeates)|8
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/91293?v=4' width='36' height='36' alt='@whiteinge'>|[@whiteinge](https://github.com/whiteinge)|8
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/117961?v=4' width='36' height='36' alt='@babilen5'>|[@babilen5](https://github.com/babilen5)|8
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/20441?v=4' width='36' height='36' alt='@iggy'>|[@iggy](https://github.com/iggy)|7
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/13106485?v=4' width='36' height='36' alt='@dynjnelson'>|[@dynjnelson](https://github.com/dynjnelson)|7
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/3449635?v=4' width='36' height='36' alt='@rominf'>|[@rominf](https://github.com/rominf)|7
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/223763?v=4' width='36' height='36' alt='@alfredopalhares'>|[@alfredopalhares](https://github.com/alfredopalhares)|6
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/1920805?v=4' width='36' height='36' alt='@alxwr'>|[@alxwr](https://github.com/alxwr)|5
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/74739?v=4' width='36' height='36' alt='@audreyfeldroy'>|[@audreyfeldroy](https://github.com/audreyfeldroy)|5
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/278900?v=4' width='36' height='36' alt='@blast-hardcheese'>|[@blast-hardcheese](https://github.com/blast-hardcheese)|5
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/2179770?v=4' width='36' height='36' alt='@gilou'>|[@gilou](https://github.com/gilou)|5
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/287147?v=4' width='36' height='36' alt='@techhat'>|[@techhat](https://github.com/techhat)|5
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/2995329?v=4' width='36' height='36' alt='@t0fik'>|[@t0fik](https://github.com/t0fik)|5
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/3768412?v=4' width='36' height='36' alt='@stp-ip'>|[@stp-ip](https://github.com/stp-ip)|4
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/1435085?v=4' width='36' height='36' alt='@blbradley'>|[@blbradley](https://github.com/blbradley)|3
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/4195158?v=4' width='36' height='36' alt='@dafyddj'>|[@dafyddj](https://github.com/dafyddj)|3
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/2192630?v=4' width='36' height='36' alt='@abrefort'>|[@abrefort](https://github.com/abrefort)|3
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/296940?v=4' width='36' height='36' alt='@renoirb'>|[@renoirb](https://github.com/renoirb)|3
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/1078927?v=4' width='36' height='36' alt='@Ken-2scientists'>|[@Ken-2scientists](https://github.com/Ken-2scientists)|2
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/22311?v=4' width='36' height='36' alt='@madssj'>|[@madssj](https://github.com/madssj)|2
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/102919?v=4' width='36' height='36' alt='@h3'>|[@h3](https://github.com/h3)|2
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/6415605?v=4' width='36' height='36' alt='@tgoodaire'>|[@tgoodaire](https://github.com/tgoodaire)|2
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/46799934?v=4' width='36' height='36' alt='@sticky-note'>|[@sticky-note](https://github.com/sticky-note)|2
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/26276?v=4' width='36' height='36' alt='@durana'>|[@durana](https://github.com/durana)|1
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/1922124?v=4' width='36' height='36' alt='@bebosudo'>|[@bebosudo](https://github.com/bebosudo)|1
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/7353491?v=4' width='36' height='36' alt='@sarcastic-coder'>|[@sarcastic-coder](https://github.com/sarcastic-coder)|1
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/458548?v=4' width='36' height='36' alt='@SuperTux88'>|[@SuperTux88](https://github.com/SuperTux88)|1
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/36720?v=4' width='36' height='36' alt='@brot'>|[@brot](https://github.com/brot)|1
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/1020898?v=4' width='36' height='36' alt='@xbglowx'>|[@xbglowx](https://github.com/xbglowx)|1
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/83323?v=4' width='36' height='36' alt='@cro'>|[@cro](https://github.com/cro)|1
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/8599847?v=4' width='36' height='36' alt='@campbellmc'>|[@campbellmc](https://github.com/campbellmc)|1
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/1233212?v=4' width='36' height='36' alt='@baby-gnu'>|[@baby-gnu](https://github.com/baby-gnu)|1
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/306240?v=4' width='36' height='36' alt='@UtahDave'>|[@UtahDave](https://github.com/UtahDave)|1
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/215487?v=4' width='36' height='36' alt='@fcrozat'>|[@fcrozat](https://github.com/fcrozat)|1
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/1468874?v=4' width='36' height='36' alt='@Laogeodritt'>|[@Laogeodritt](https://github.com/Laogeodritt)|1
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/650691?v=4' width='36' height='36' alt='@itbabu'>|[@itbabu](https://github.com/itbabu)|1
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/296523?v=4' width='36' height='36' alt='@mkotsbak'>|[@mkotsbak](https://github.com/mkotsbak)|1
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/1331128?v=4' width='36' height='36' alt='@mattysads'>|[@mattysads](https://github.com/mattysads)|1
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/3705387?v=4' width='36' height='36' alt='@mbrannigan'>|[@mbrannigan](https://github.com/mbrannigan)|1
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/3433835?v=4' width='36' height='36' alt='@n-rodriguez'>|[@n-rodriguez](https://github.com/n-rodriguez)|1
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/8399114?v=4' width='36' height='36' alt='@fortunejuggle'>|[@fortunejuggle](https://github.com/fortunejuggle)|1
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/219695?v=4' width='36' height='36' alt='@rmoorman'>|[@rmoorman](https://github.com/rmoorman)|1
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/154676?v=4' width='36' height='36' alt='@skurfer'>|[@skurfer](https://github.com/skurfer)|1
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/2592431?v=4' width='36' height='36' alt='@RobRuana'>|[@RobRuana](https://github.com/RobRuana)|1
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/10464711?v=4' width='36' height='36' alt='@sbrefort'>|[@sbrefort](https://github.com/sbrefort)|1
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/125458?v=4' width='36' height='36' alt='@sbellem'>|[@sbellem](https://github.com/sbellem)|1
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/500703?v=4' width='36' height='36' alt='@retrry'>|[@retrry](https://github.com/retrry)|1
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/2814878?v=4' width='36' height='36' alt='@thomasrossetto'>|[@thomasrossetto](https://github.com/thomasrossetto)|1
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/507599?v=4' width='36' height='36' alt='@thatch45'>|[@thatch45](https://github.com/thatch45)|1
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/444668?v=4' width='36' height='36' alt='@tobio'>|[@tobio](https://github.com/tobio)|1
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/2097647?v=4' width='36' height='36' alt='@XRasher'>|[@XRasher](https://github.com/XRasher)|1
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/8005290?v=4' width='36' height='36' alt='@YetAnotherMinion'>|[@YetAnotherMinion](https://github.com/YetAnotherMinion)|1
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/17393048?v=4' width='36' height='36' alt='@ek9'>|[@ek9](https://github.com/ek9)|1
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/11394644?v=4' width='36' height='36' alt='@Strade288'>|[@Strade288](https://github.com/Strade288)|1
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/52996?v=4' width='36' height='36' alt='@daks'>|[@daks](https://github.com/daks)|1

---

Auto-generated by a [forked version](https://github.com/myii/maintainer) of [gaocegege/maintainer](https://github.com/gaocegege/maintainer) on 2021-07-06.

==> v0.42.0.zip: postgres-formula/AUTHORS.md <==
# Authors

This list is sorted by the number of commits per contributor in _descending_ order.

Avatar|Contributor|Contributions
:-:|---|:-:
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/10231489?v=4' width='36' height='36' alt='@myii'>|[@myii](https://github.com/myii)|156
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/13322818?v=4' width='36' height='36' alt='@noelmcloughlin'>|[@noelmcloughlin](https://github.com/noelmcloughlin)|78
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/1800660?v=4' width='36' height='36' alt='@aboe76'>|[@aboe76](https://github.com/aboe76)|54
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/1396878?v=4' width='36' height='36' alt='@gravyboat'>|[@gravyboat](https://github.com/gravyboat)|41
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/242396?v=4' width='36' height='36' alt='@javierbertoli'>|[@javierbertoli](https://github.com/javierbertoli)|21
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/3374962?v=4' width='36' height='36' alt='@nmadhok'>|[@nmadhok](https://github.com/nmadhok)|19
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/16338056?v=4' width='36' height='36' alt='@vutny'>|[@vutny](https://github.com/vutny)|18
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/528061?v=4' width='36' height='36' alt='@puneetk'>|[@puneetk](https://github.com/puneetk)|11
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/745513?v=4' width='36' height='36' alt='@EvaSDK'>|[@EvaSDK](https://github.com/EvaSDK)|9
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/1713422?v=4' width='36' height='36' alt='@dferramosi'>|[@dferramosi](https://github.com/dferramosi)|8
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/5306980?v=4' width='36' height='36' alt='@johnkeates'>|[@johnkeates](https://github.com/johnkeates)|8
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/91293?v=4' width='36' height='36' alt='@whiteinge'>|[@whiteinge](https://github.com/whiteinge)|8
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/117961?v=4' width='36' height='36' alt='@babilen5'>|[@babilen5](https://github.com/babilen5)|8
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/20441?v=4' width='36' height='36' alt='@iggy'>|[@iggy](https://github.com/iggy)|7
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/13106485?v=4' width='36' height='36' alt='@dynjnelson'>|[@dynjnelson](https://github.com/dynjnelson)|7
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/3449635?v=4' width='36' height='36' alt='@rominf'>|[@rominf](https://github.com/rominf)|7
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/1920805?v=4' width='36' height='36' alt='@alxwr'>|[@alxwr](https://github.com/alxwr)|5
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/74739?v=4' width='36' height='36' alt='@audreyfeldroy'>|[@audreyfeldroy](https://github.com/audreyfeldroy)|5
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/278900?v=4' width='36' height='36' alt='@blast-hardcheese'>|[@blast-hardcheese](https://github.com/blast-hardcheese)|5
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/2179770?v=4' width='36' height='36' alt='@gilou'>|[@gilou](https://github.com/gilou)|5
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/287147?v=4' width='36' height='36' alt='@techhat'>|[@techhat](https://github.com/techhat)|5
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/2995329?v=4' width='36' height='36' alt='@t0fik'>|[@t0fik](https://github.com/t0fik)|5
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/3768412?v=4' width='36' height='36' alt='@stp-ip'>|[@stp-ip](https://github.com/stp-ip)|4
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/1435085?v=4' width='36' height='36' alt='@blbradley'>|[@blbradley](https://github.com/blbradley)|3
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/4195158?v=4' width='36' height='36' alt='@dafyddj'>|[@dafyddj](https://github.com/dafyddj)|3
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/2192630?v=4' width='36' height='36' alt='@abrefort'>|[@abrefort](https://github.com/abrefort)|3
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/296940?v=4' width='36' height='36' alt='@renoirb'>|[@renoirb](https://github.com/renoirb)|3
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/1078927?v=4' width='36' height='36' alt='@Ken-2scientists'>|[@Ken-2scientists](https://github.com/Ken-2scientists)|2
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/22311?v=4' width='36' height='36' alt='@madssj'>|[@madssj](https://github.com/madssj)|2
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/102919?v=4' width='36' height='36' alt='@h3'>|[@h3](https://github.com/h3)|2
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/6415605?v=4' width='36' height='36' alt='@tgoodaire'>|[@tgoodaire](https://github.com/tgoodaire)|2
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/46799934?v=4' width='36' height='36' alt='@sticky-note'>|[@sticky-note](https://github.com/sticky-note)|2
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/26276?v=4' width='36' height='36' alt='@durana'>|[@durana](https://github.com/durana)|1
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/1922124?v=4' width='36' height='36' alt='@bebosudo'>|[@bebosudo](https://github.com/bebosudo)|1
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/7353491?v=4' width='36' height='36' alt='@sarcastic-coder'>|[@sarcastic-coder](https://github.com/sarcastic-coder)|1
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/458548?v=4' width='36' height='36' alt='@SuperTux88'>|[@SuperTux88](https://github.com/SuperTux88)|1
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/36720?v=4' width='36' height='36' alt='@brot'>|[@brot](https://github.com/brot)|1
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/1020898?v=4' width='36' height='36' alt='@xbglowx'>|[@xbglowx](https://github.com/xbglowx)|1
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/83323?v=4' width='36' height='36' alt='@cro'>|[@cro](https://github.com/cro)|1
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/8599847?v=4' width='36' height='36' alt='@campbellmc'>|[@campbellmc](https://github.com/campbellmc)|1
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/1233212?v=4' width='36' height='36' alt='@baby-gnu'>|[@baby-gnu](https://github.com/baby-gnu)|1
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/306240?v=4' width='36' height='36' alt='@UtahDave'>|[@UtahDave](https://github.com/UtahDave)|1
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/215487?v=4' width='36' height='36' alt='@fcrozat'>|[@fcrozat](https://github.com/fcrozat)|1
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/1468874?v=4' width='36' height='36' alt='@Laogeodritt'>|[@Laogeodritt](https://github.com/Laogeodritt)|1
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/650691?v=4' width='36' height='36' alt='@itbabu'>|[@itbabu](https://github.com/itbabu)|1
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/296523?v=4' width='36' height='36' alt='@mkotsbak'>|[@mkotsbak](https://github.com/mkotsbak)|1
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/1331128?v=4' width='36' height='36' alt='@mattysads'>|[@mattysads](https://github.com/mattysads)|1
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/3705387?v=4' width='36' height='36' alt='@mbrannigan'>|[@mbrannigan](https://github.com/mbrannigan)|1
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/3433835?v=4' width='36' height='36' alt='@n-rodriguez'>|[@n-rodriguez](https://github.com/n-rodriguez)|1
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/8399114?v=4' width='36' height='36' alt='@fortunejuggle'>|[@fortunejuggle](https://github.com/fortunejuggle)|1
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/152786?v=4' width='36' height='36' alt='@droope'>|[@droope](https://github.com/droope)|1
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/219695?v=4' width='36' height='36' alt='@rmoorman'>|[@rmoorman](https://github.com/rmoorman)|1
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/154676?v=4' width='36' height='36' alt='@skurfer'>|[@skurfer](https://github.com/skurfer)|1
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/2592431?v=4' width='36' height='36' alt='@RobRuana'>|[@RobRuana](https://github.com/RobRuana)|1
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/10464711?v=4' width='36' height='36' alt='@sbrefort'>|[@sbrefort](https://github.com/sbrefort)|1
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/125458?v=4' width='36' height='36' alt='@sbellem'>|[@sbellem](https://github.com/sbellem)|1
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/500703?v=4' width='36' height='36' alt='@retrry'>|[@retrry](https://github.com/retrry)|1
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/2814878?v=4' width='36' height='36' alt='@thomasrossetto'>|[@thomasrossetto](https://github.com/thomasrossetto)|1
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/507599?v=4' width='36' height='36' alt='@thatch45'>|[@thatch45](https://github.com/thatch45)|1
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/444668?v=4' width='36' height='36' alt='@tobio'>|[@tobio](https://github.com/tobio)|1
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/2097647?v=4' width='36' height='36' alt='@XRasher'>|[@XRasher](https://github.com/XRasher)|1
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/8005290?v=4' width='36' height='36' alt='@YetAnotherMinion'>|[@YetAnotherMinion](https://github.com/YetAnotherMinion)|1
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/17393048?v=4' width='36' height='36' alt='@ek9'>|[@ek9](https://github.com/ek9)|1
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/11394644?v=4' width='36' height='36' alt='@Strade288'>|[@Strade288](https://github.com/Strade288)|1
<img class='float-left rounded-1' src='https://avatars.githubusercontent.com/u/52996?v=4' width='36' height='36' alt='@daks'>|[@daks](https://github.com/daks)|1

---

Auto-generated by a [forked version](https://github.com/myii/maintainer) of [gaocegege/maintainer](https://github.com/gaocegege/maintainer) on 2021-07-15.
